<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

class Ultimate_AI_Chat_Assistant_Controller
{
    private $Chat_Assistant_Manager;

    public function __construct()
    {
        $this->Chat_Assistant_Manager = new Ultimate_AI_Chat_Assistant();
        add_action('wp_ajax_ultimate_ai_create_chat_assistant', [$this, 'ultimate_ai_create_chat_assistant']);
        add_action('wp_ajax_ultimate_ai_get_all_chat_assistants', [$this, 'ultimate_ai_get_all_chat_assistants']);
        add_action('wp_ajax_ultimate_ai_delete_chat_assistant', [$this, 'ultimate_ai_delete_chat_assistant']);
        add_action('wp_ajax_ultimate_ai_update_chat_assistant', [$this, 'ultimate_ai_update_chat_assistant']);
    }

    public function ultimate_ai_create_chat_assistant()
    {
        $name = sanitize_text_field($_POST['name']);
        $desc = sanitize_text_field($_POST['description']);
        $prompt = sanitize_text_field($_POST['prompt']);
        $icon_url = sanitize_text_field($_POST['icon_url']);
        $id = sanitize_text_field($_POST['id']);
        $res = $this->Chat_Assistant_Manager->ultimate_ai_create_chat_assistant($name, $prompt, $desc, $icon_url, $id);
        if (!$res['is_success']) {
            wp_send_json(['data' => $res['message']], 400);
        }
        wp_send_json(['data' => $res['data']], 200);
    }

    public function ultimate_ai_get_all_chat_assistants()
    {
        $chat_assistants = $this->Chat_Assistant_Manager->ultimate_ai_get_chat_assistants();
        wp_send_json(['data' => $chat_assistants], 200);
    }

    // ========= Delete chat assistant =========================
    public function ultimate_ai_delete_chat_assistant()
    {
        $assistant_id = (int) sanitize_text_field($_POST['id']);

        $delete_result = $this->Chat_Assistant_Manager->ultimate_ai_delete_chat_assistant($assistant_id);

        if (!$delete_result['success']) {
            wp_send_json(['data' => 'Chat assistant deletion failed. '.$delete_result['message']], 400);
        }

        wp_send_json(['data' => 'Chat assistant deleted successfully'], 200);
    }

    // ===================== update_chat_assistant ==================
    public function ultimate_ai_update_chat_assistant()
    {
        $key_name = sanitize_key($_POST['key_name']);
        $value = rest_sanitize_boolean($_POST['value']);
        $chat_id = (int) sanitize_text_field($_POST['chat_id']);
        $is_direct_meta = true; // hard coded for now
        $res = $this->Chat_Assistant_Manager->ultimate_ai_update_chat_assistant_meta($key_name, $value, $chat_id, $is_direct_meta);

        if (!$res['is_success']) {
            wp_send_json(['data' => $res['message']], 400);
        }

        wp_send_json(['data' => $res['data']], 200);
    }
}
new Ultimate_AI_Chat_Assistant_Controller();
